package com.ruoyi.asset.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.asset.domain.TbAsset;

/**
 * 资产信息Service接口
 * 
 * @author 原动力
 * @date 2023-03-27
 */
public interface ITbAssetService extends IService<TbAsset>
{
    /**
     * 查询资产信息
     * 
     * @param id 资产信息主键
     * @return 资产信息
     */
    public TbAsset selectTbAssetById(Long id);

    /**
     * 查询资产信息列表
     * 
     * @param tbAsset 资产信息
     * @return 资产信息集合
     */
    public List<TbAsset> selectTbAssetList(TbAsset tbAsset);

    /**
     * 新增资产信息
     * 
     * @param tbAsset 资产信息
     * @return 结果
     */
    public int insertTbAsset(TbAsset tbAsset);

    /**
     * 修改资产信息
     * 
     * @param tbAsset 资产信息
     * @return 结果
     */
    public int updateTbAsset(TbAsset tbAsset);

    /**
     * 批量删除资产信息
     * 
     * @param ids 需要删除的资产信息主键集合
     * @return 结果
     */
    public int deleteTbAssetByIds(Long[] ids);

    /**
     * 删除资产信息信息
     * 
     * @param id 资产信息主键
     * @return 结果
     */
    public int deleteTbAssetById(Long id);

    /**
     * 根据条形码查询资产信息
     *
     * @param barCode 资产条形码
     * @return 资产信息
     */
    TbAsset selectTbAssetByBarCode(String barCode);
}
