package com.ruoyi.asset.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.asset.domain.TbAsset;
import com.ruoyi.asset.service.ITbAssetService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 资产信息Controller
 * 
 * @author 原动力
 * @date 2023-03-27
 */
@RestController
@RequestMapping("/asset/asset")
public class TbAssetController extends BaseController
{
    @Autowired
    private ITbAssetService tbAssetService;

    /**
     * 查询资产信息列表
     */
    @PreAuthorize("@ss.hasPermi('asset:asset:list')")
    @GetMapping("/list")
    public TableDataInfo list(TbAsset tbAsset)
    {
        startPage();
        List<TbAsset> list = tbAssetService.selectTbAssetList(tbAsset);
        return getDataTable(list);
    }

    /**
     * 导出资产信息列表
     */
    @PreAuthorize("@ss.hasPermi('asset:asset:export')")
    @Log(title = "资产信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TbAsset tbAsset)
    {
        List<TbAsset> list = tbAssetService.selectTbAssetList(tbAsset);
        ExcelUtil<TbAsset> util = new ExcelUtil<TbAsset>(TbAsset.class);
        util.exportExcel(response, list, "资产信息数据");
    }

    /**
     * 获取资产信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('asset:asset:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(tbAssetService.selectTbAssetById(id));
    }

    /**
     * 新增资产信息
     */
    @PreAuthorize("@ss.hasPermi('asset:asset:add')")
    @Log(title = "资产信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TbAsset tbAsset)
    {
        return toAjax(tbAssetService.insertTbAsset(tbAsset));
    }

    /**
     * 修改资产信息
     */
    @PreAuthorize("@ss.hasPermi('asset:asset:edit')")
    @Log(title = "资产信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TbAsset tbAsset)
    {
        return toAjax(tbAssetService.updateTbAsset(tbAsset));
    }

    /**
     * 删除资产信息
     */
    @PreAuthorize("@ss.hasPermi('asset:asset:remove')")
    @Log(title = "资产信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tbAssetService.deleteTbAssetByIds(ids));
    }

    /**
     * 根据条形码获取资产信息
     */
    @PreAuthorize("@ss.hasPermi('asset:asset:query')")
    @GetMapping(value = "/barcode/{barCode}")
    public AjaxResult selectTbAssetByBarCode(@PathVariable("barCode") String barCode) {
        return AjaxResult.success(tbAssetService.selectTbAssetByBarCode(barCode));
    }
}
